Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(151)

Unified Diff: src/platform.h

Issue 385069: Fix some style issues in the ARM code.... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/platform.h
===================================================================
--- src/platform.h (revision 3292)
+++ src/platform.h (working copy)
@@ -250,8 +250,9 @@
// Returns the double constant NAN
static double nan_value();
- // Support runtime detection of VFP3 on linux platforms.
- static bool fgrep_vfp(const char * file_name, const char * string);
+ // Support runtime detection of VFP3 on ARM CPUs.
+ enum CpuFeature { VFP };
+ static bool ArmCpuHasFeature(CpuFeature feature);
// Returns the activation frame alignment constraint or zero if
// the platform doesn't care. Guaranteed to be a power of two.
« src/arm/codegen-arm.cc ('K') | « src/flag-definitions.h ('k') | src/platform-linux.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698